@@ -31,7 +31,9 @@
 class WSCstring;
 
 class WSDfont  :public WSDres{
-
+    WSCstring _virtual_name;
+  protected:
+    WSCbool _virtual_flag;
   public:
     WSDfont();
     virtual ~WSDfont();
@@ -48,6 +50,7 @@ class WSDfont  :public WSDres{
 
     long getStringWidth(char*,long en = WS_EN_DEFAULT);
     long getStringHeight(char*,long en = WS_EN_DEFAULT);
+    void setVirtualFlag(WSCbool);
 
     WSMFclassDef(WSDfont,WSDres);
 };
