@@ -51,6 +51,7 @@ static WSCbool _expose_sequence;
 static WSClistData _geometry_update_list;
 static WSClistData _update_list;
 static WSClistData _expose_list;
+static WSClistData _recursive_update_list;
 static short _global_region_x;
 static short _global_region_y;
 static WSCushort _global_region_w;
@@ -152,9 +153,11 @@ virtual void _clear_area( long x,long y,WSCulong w,WSCulong h);
   virtual long exposeArea(long x,long y,WSCulong w,WSCulong h,WSCbool scaling = True);    
   void addUpdateList();
   void addGeometryUpdateList();
+  void addRecursiveUpdateList();
 static void executeUpdate();
 static void setGlobalRegion(short x,short y,WSCushort,WSCushort);
 static void getGlobalRegion(short* x,short* y,WSCushort*,WSCushort*);
+virtual void recursive_update();
 
   WSMFclassDef(WSDbtronFormDev,WSDwindowDev);
 };
