@@ -130,7 +130,7 @@
   WSGIappLocaleSet()->setLocaleString("C","R3:WSSTR Compiler flags","Compiler flags");
   WSGIappLocaleSet()->setLocaleString("C","S3:WSSTR Compile mode","Compile mode");
   WSGIappLocaleSet()->setLocaleString("C","T3:WSSTR  Debug mode"," Debug mode");
-  WSGIappLocaleSet()->setLocaleString("C","U3:WSSTR Class library","Class library");
+  WSGIappLocaleSet()->setLocaleString("C","U3:WSSTR Application type","Application type");
   WSGIappLocaleSet()->setLocaleString("C","V3:WSSTR  Generate class library"," Generate class library");
   WSGIappLocaleSet()->setLocaleString("C","W3:WSSTR Compiler","Compiler");
   WSGIappLocaleSet()->setLocaleString("C","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","Runtime mode,Debug mode,Runtime static mode,Debug static mode");
