@@ -130,7 +130,7 @@
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","R3:WSSTR Compiler flags","共通コンパイルフラグ");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","S3:WSSTR Compile mode","コンパイル方法");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","T3:WSSTR  Debug mode"," デバッグモード");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","U3:WSSTR Class library","クラスライブラリ");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","U3:WSSTR Application type","ビルドタイプ");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","V3:WSSTR  Generate class library"," クラスライブラリにする");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","W3:WSSTR Compiler","コンパイラ");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","通常モード,デバッグモード,通常スタティックモード,デバッグスタティックモード");
