@@ -879,7 +879,7 @@ void WSCinspector::_float_vis_work2(WSCbase* fform){
     obj->setManaged(obj->_sform,True);
   }else{
     obj->_sform->setManaged(fform,False);
-printf("WSCinspector::_float_vis_work2 %d,%d\n",obj->_sform->getManaged(obj->_mfform),obj->_sform->getManaged(obj->_sform2));
+//printf("WSCinspector::_float_vis_work2 %d,%d\n",obj->_sform->getManaged(obj->_mfform),obj->_sform->getManaged(obj->_sform2));
     if (obj->_sform->getManaged(obj->_sform2) == False ){
       obj->_sform->setVisible(False);
       obj->setManaged(obj->_sform,False);
@@ -896,7 +896,7 @@ void WSCinspector::_float_vis_work3(WSCbase* fform){
     obj->_sform->setManaged(obj->_sform2,True);
   }else{
     obj->_sform2->setManaged(fform,False);
-printf("WSCinspector::_float_vis_work3 %d,%d\n", obj->_sform2->getManaged(obj->_fform), obj->_sform2->getManaged(obj->_ifform));
+//printf("WSCinspector::_float_vis_work3 %d,%d\n", obj->_sform2->getManaged(obj->_fform), obj->_sform2->getManaged(obj->_ifform));
     if (obj->_sform2->getManaged(obj->_fform) == False &&
         obj->_sform2->getManaged(obj->_ifform) == False ){
       obj->_sform->setManaged(obj->_sform2,False);
