@@ -32,6 +32,7 @@ WSMFclassInit(WSDimage,WSDres);
 WSDimage::WSDimage(){
  _w = 0;
  _h = 0;
+ _mode = 0;
 // _bitmap = 0;
 }
 
@@ -79,3 +80,9 @@ WSCbool WSDimage::getReady(){
   }
   return True; 
 }
+void WSDimage::setImageMode(WSCulong val){
+  _mode = val;
+}
+WSCulong WSDimage::getImageMode(){
+  return _mode;
+}
