@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 Toshikaz Hirabayashi
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -31,7 +31,7 @@
 #include <WSDimage.h>
 #include <WSCimageSet.h>
 #include <WSCstring.h>
-#include <WSCvarc.h>
+//#include <WSCvarc.h>
 #include <WSClocaleSet.h>
 #include <WSDpsdraw.h>
 #include <WSDmwindowDev.h>
