@@ -2835,6 +2835,7 @@ static  char output[2048];
      }
      char jish[4];
      char jist[5];
+     char jist3[5];
      char jist2[4];
      jish[0] = 0x1b;
      jish[1] = ')';
@@ -2847,6 +2848,13 @@ static  char output[2048];
      jist[3] = 'B';
      jist[4] = 0;
 
+     jist3[0] = 0x1b;
+     jist3[1] = '$';
+     jist3[2] = '(';
+     jist3[3] = 'B';
+     jist3[4] = 0;
+
+
      jist2[0] = 0x1b;
      jist2[1] = '(';
      jist2[2] = 'B';
@@ -2861,13 +2869,14 @@ static  char output[2048];
          p++;
          i++;
          fl = 1;//hankaku kana mode
-     }else if(!strncmp(jist,buf,4)){
+     }else if(!strncmp(jist,buf,4) || !strncmp(jist3,buf,4)){
+printf("kanjimode!! %d\n",i);
          buf = buf +4;
-         output[i] = *buf;
+         output[i] = (*buf | 0x80);
          buf++;
          p++;
          i++;
-         output[i] = *buf;
+         output[i] = (*buf | 0x80);
          buf++;
          p++;
          i++;
@@ -2880,7 +2889,17 @@ static  char output[2048];
          i++;
          fl = 0;//ascii mode
      }else{
-       if (!(*buf & 0x80) && (*buf >= 0x20)){
+       if (fl == 2){ //kanji mode
+         output[i] = (*buf | 0x80);
+         i++;
+         buf++;
+         p++;
+         output[i] = (*buf | 0x80);
+         i++;
+         buf++;
+         p++;
+printf("output=#%s#\n",output);
+       }else if (!(*buf & 0x80) && (*buf >= 0x20)){
          output[i] = *buf;
          i++;
          buf++;
@@ -2892,15 +2911,6 @@ static  char output[2048];
          i++;
          buf++;
          p++;
-       }else if (fl == 2){ //kanji mode
-         output[i] = *buf;
-         i++;
-         buf++;
-         p++;
-         output[i] = *buf;
-         i++;
-         buf++;
-         p++;
        }else{
          buf++;
          p++;
