@@ -46,6 +46,7 @@
 //#include <btron/WSDunixExecute.h>
 #include <WSDfile.h>
 #include <btron/WSDbtronFormDev.h>
+#include <btron/WSDbtronThread.h>
 #ifdef TE
 #include <btron/errcode.h>
 #else
@@ -761,6 +762,18 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d APPL5x2 start\n",__FILE__,__LINE__);
     }
 dbprintf("WSDxappDev::_dispatchEvent %s:%d APPL5x2 done\n",__FILE__,__LINE__);
 #endif
+  }else if (msg->msg_type == MS_TYPE4){ 
+dbprintf("WSDxappDev::_dispatchEvent %s:%d APPL5x start\n",__FILE__,__LINE__);
+    WSDbtronThread* th = NULL;
+    memcpy(&th,msg->msg_body.ANYMSG.msg_str,sizeof(W));
+    if (th->getCallbackFunction() != NULL){
+//printf("client message !! here! execute exec_read\n");
+      void(*fn)(WSDbtronThread*,void*) =
+           (void(*)(WSDbtronThread*,void*))th->getCallbackFunction();
+      if (fn != NULL){
+        fn(th,th->getCallbackData());
+      }
+    }
   }
 }
 
