@@ -63,6 +63,7 @@ WSCbool WSDbtronFormDev::_expose_sequence = 0;
 WSClistData WSDbtronFormDev::_update_list;
 WSClistData WSDbtronFormDev::_geometry_update_list;
 WSClistData WSDbtronFormDev::_expose_list;
+WSClistData WSDbtronFormDev::_recursive_update_list;
 
 short WSDbtronFormDev::_global_region_x = 0;
 short WSDbtronFormDev::_global_region_y = 0;
@@ -273,7 +274,6 @@ dbprintf("WSDbtronFormDev::setValue need implement!!!!! %s:%d\n",__FILE__,__LINE
   WSDwindowDev::setValue(kind,data);
   return WS_NO_ERR;
 }
-
 void WSDbtronFormDev::_copy_area(long x,long y,WSCulong w,WSCulong h,long dx,long dy,WSCuchar fl){
 
 //printf("WSDbtronFormDev::_copy_area %d,%d,%d,%d -> %d,%d %s\n",x,y,w,h,dx,dy,getAttachedClient()->getInstanceName());
@@ -712,7 +712,9 @@ void WSDbtronFormDev::recursiveExposeExecute(short x,short y,WSCushort w,WSCusho
   _setup_pixmap(x,y,w,h,_bg,_bg_pix);
 
   exposeExecute(x,y,w,h);
-
+#ifdef F_MEMGID
+  _copy_area(x,y,w,h,x,y,WS_PIXMAP_TO_WINDOW);
+#endif
   short px,py;
   getAbstPos(&px,&py);
 #ifdef F_MEMGID
@@ -731,7 +733,9 @@ void WSDbtronFormDev::recursiveExposeExecute(short x,short y,WSCushort w,WSCusho
       long dx,dy;
       WSCulong dw,dh;
       WSGFandArea(cx,cy,cw,ch,x+px,y+py,w,h,&dx,&dy,&dw,&dh);
-      child->recursiveExposeExecute(dx -cx, dy -cy, dw+1, dh+1);
+      short px2,py2;
+      child->getAbstPos(&px2,&py2);
+      child->recursiveExposeExecute(dx -px2, dy -py2, dw+1, dh+1);
     }
   }
 #endif
@@ -1908,6 +1912,17 @@ void WSDbtronFormDev::addUpdateList(){
   }
   _update_list.add((void*)this);
 }
+void WSDbtronFormDev::addRecursiveUpdateList(){
+  long num = _recursive_update_list.getNum();
+  long i;
+  for(i=0; i<num; i++){
+    WSDbtronFormDev* item =(WSDbtronFormDev*)_recursive_update_list[i];
+    if (item == this){
+      return;
+    }
+  }
+  _recursive_update_list.add((void*)this);
+}
 void WSDbtronFormDev::addGeometryUpdateList(){
   long num = _geometry_update_list.getNum();
   long i;
@@ -1999,6 +2014,31 @@ void WSDbtronFormDev::executeUpdate(){
     }
   }
   _update_list.clear();
+
+  WSClistData recursive_ulist;
+  num = _recursive_update_list.getNum();
+  for(i=0; i<num; i++){
+    WSDbtronFormDev* item =(WSDbtronFormDev*)_recursive_update_list[i];
+    if (item != NULL && isValidInstance(item) != False &&
+        item->getParentVisible() != False){
+      long j;
+      W wid = (W)item->getWindowResource();
+      long update = True;
+      long unum = _expose_list.getNum();
+      for(j=0; j<unum;j++){
+        W item = (W)_expose_list[j];
+        if (item == wid){
+          update = False;
+          break;
+        }
+      }
+      if (update == True){
+        recursive_ulist.add((void*)item);
+      }
+    }
+  }
+  _recursive_update_list.clear();
+
   num = _expose_list.getNum();
   for(i=0; i<num; i++){
     W wid = (W)_expose_list[i];
@@ -2030,8 +2070,16 @@ void WSDbtronFormDev::executeUpdate(){
 dbprintf("WSDbtronFormDev::execUpdate update wid=0x%x ret=0x%x\n",wid,ret);
   }
   _expose_list.clear();
-}
 
+  num = recursive_ulist.getNum();
+  for(i=0; i<num; i++){
+    WSDbtronFormDev* item =(WSDbtronFormDev*)recursive_ulist[i];
+    item->recursive_update();
+  }
+}
+void WSDbtronFormDev::recursive_update(){
+  recursiveExposeExecute(0,0,_w_w,_w_h);
+}
 long WSDbtronFormDev::exposeArea(long x,long y,WSCulong w,WSCulong h,WSCbool scale){
 
   short ax,ay;
