@@ -57,7 +57,7 @@ long WSGFbtronBufToPixmapG(unsigned char *buf,W* pixmap,long width,long height,l
 long WSGFbtronBmpReadFpToPixmap(FILE* ifile,W* pixmap,W*,long* w,long* h,UB**,UB**);
 long WSGFbtronBmpReadFileToPixmap(char* filename,W* pixmap,W*,long* w,long* h,UB**,UB**);
 long PngReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB**,UB**);
-extern long JpegReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB**,UB**,WSCbool reuse_mem);
+extern long JpegReadFileToPixmap(char* filename,long size,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB**,UB**,WSCbool reuse_mem);
 
 
 WSMFclassInit(WSDbtronImage,WSDimage);
@@ -116,14 +116,35 @@ dbprintf("IMG>> WSDbtronImage::initialize img=%s\n",in.getString());
      long height = _h;
      char* load_file_name = in.getString();
      long reti = 0;
-     if (_mode & WS_IMAGE_MODE_REUSE_MEM){
-       reti = JpegReadFileToPixmap( load_file_name, &mem_gid,&mem_gid2,
-                                  &width,&height,&_pix_buf,&_pix_buf2,True);
-     }else{
-       reti = JpegReadFileToPixmap( load_file_name, &mem_gid,&mem_gid2,
-                                  &width,&height,&_pix_buf,&_pix_buf2,False);
-     }
 
+     if (strncmp("http://",in.getString(),7)){
+       if (_mode & WS_IMAGE_MODE_REUSE_MEM){
+         reti = JpegReadFileToPixmap( load_file_name,0, &mem_gid,&mem_gid2,
+                                  &width,&height,&_pix_buf,&_pix_buf2,True);
+       }else{
+         reti = JpegReadFileToPixmap( load_file_name,0, &mem_gid,&mem_gid2,
+                                  &width,&height,&_pix_buf,&_pix_buf2,False);
+       }
+     }else{
+       char*  pbuf = NULL;
+       long size = 0;
+       long reti;
+       char*  ctype = NULL;
+       long  ishtml = 0;
+       WSGFloadRemoteFile(in.getString(),&pbuf,&ctype,&size,&ishtml,1);
+       if (pbuf != NULL){
+         if (_mode & WS_IMAGE_MODE_REUSE_MEM){
+           reti = JpegReadFileToPixmap( pbuf,size, &mem_gid,&mem_gid2,
+                                  &width,&height,&_pix_buf,&_pix_buf2,True);
+         }else{
+           reti = JpegReadFileToPixmap( pbuf,size, &mem_gid,&mem_gid2,
+                                  &width,&height,&_pix_buf,&_pix_buf2,False);
+         }
+         free(pbuf);
+       }else{
+         reti = 1;
+       }
+     }
      if (mem_gid == 0){
        mem_gid = -1;
      }
@@ -1459,10 +1480,83 @@ void jpeg_stdio_src (j_decompress_ptr cinfo, FILE * infile){
 }
 #endif //BTRON_ADDED
 
-long JpegReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB** ptr1,UB** ptr2,WSCbool reuse_mem){
-    FILE* ifile = fopen(filename,"r");
-    if (ifile == NULL){
-      return -1;
+typedef struct {
+  struct jpeg_source_mgr pub;
+  char* buf;
+  char buf_term[2];
+  long buf_size;
+  long pos;
+  WSCbool read_started;
+}buf_source_mgr;
+
+void init_source_from_buf(j_decompress_ptr cinfo){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  src->read_started = True;
+}
+
+void skip_input_data_from_buf(j_decompress_ptr cinfo, long nbytes){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  if (nbytes > 0) {
+    src->pub.next_input_byte += (size_t) nbytes;
+    src->pub.bytes_in_buffer -= (size_t) nbytes;
+  }
+}
+
+boolean fill_input_buffer_from_buf(j_decompress_ptr cinfo){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+
+  if (src->pos == src->buf_size){
+    src->buf_term[0] = (JOCTET) 0xFF;
+    src->buf_term[1] = (JOCTET) JPEG_EOI;
+    src->pub.next_input_byte = (JOCTET*)src->buf_term;
+    src->pub.bytes_in_buffer = 2;
+    src->read_started = False;
+    return TRUE;
+  }
+
+  src->pub.next_input_byte = (JOCTET*)src->buf;
+  src->pub.bytes_in_buffer = src->buf_size;
+  src->pos = src->buf_size;
+  src->read_started = False;
+
+  return TRUE;
+}
+
+void term_source_from_buf(j_decompress_ptr cinfo){
+}
+
+void jpeg_buf_src (j_decompress_ptr cinfo, char* buf,long size){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  if (cinfo->src == NULL) {
+    cinfo->src = (struct jpeg_source_mgr *)
+      (*cinfo->mem->alloc_small) ((j_common_ptr) cinfo, JPOOL_PERMANENT,
+                 sizeof(buf_source_mgr));
+    src = (buf_source_mgr*) cinfo->src;
+  }
+
+  src = (buf_source_mgr*) cinfo->src;
+  src->pub.init_source = init_source_from_buf;
+  src->pub.fill_input_buffer = fill_input_buffer_from_buf;
+  src->pub.skip_input_data = skip_input_data_from_buf;
+  src->pub.resync_to_restart = jpeg_resync_to_restart;
+  src->pub.term_source = term_source_from_buf;
+  src->pub.bytes_in_buffer = 0;
+  src->pub.next_input_byte = (JOCTET*)NULL;
+
+  src->buf = buf;
+  src->read_started = False;
+  src->buf_size = size;
+  src->pos = 0;
+}
+
+
+long JpegReadFileToPixmap(char* filename,long size,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB** ptr1,UB** ptr2,WSCbool reuse_mem){
+    FILE* ifile = NULL;
+    if (size == 0){
+      ifile = fopen(filename,"r");
+      if (ifile == NULL){
+        return -1;
+      }
     }
     struct jpeg_decompress_struct    jinf;
     struct jpeg_error_mgr            jerr;
@@ -1473,9 +1567,18 @@ long JpegReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long
 
     jpeg_create_decompress(&jinf);
     jpeg_set_marker_processor(&jinf,JPEG_COM,chandler);
-
-    jpeg_stdio_src(&jinf,ifile);
-    jpeg_read_header(&jinf,TRUE);
+    if (size == 0){
+      jpeg_stdio_src(&jinf,ifile);
+    }else{
+      jpeg_buf_src(&jinf,filename,size);
+    }
+    long reti = jpeg_read_header(&jinf,TRUE);
+    if (reti != JPEG_HEADER_OK){
+      if (size == 0){
+        fclose(ifile);
+      }
+      return -1;
+    }
     jpeg_calc_output_dimensions(&jinf);
     jpeg_start_decompress(&jinf);
 
@@ -1515,7 +1618,7 @@ long JpegReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long
       rowptr[0] = (JSAMPROW)&(buf[i * rwidth * components]);
       jpeg_read_scanlines(&jinf, rowptr,1);
     }
-//printf("before read scanline done..\n");
+//printf("before read scanline done.. components=%d\n",components);
     if (components == 4){
       WSGFbtronBufToPixmap2(buf, mem_gid,mem_gid2,rwidth,rheight,w,h,components*rwidth*sizeof(JSAMPLE),ptr1,ptr2,reuse_mem);
     }else
@@ -1536,7 +1639,9 @@ long JpegReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long
       }
       jpeg_finish_decompress(&jinf);
       jpeg_destroy_decompress(&jinf);
-      fclose(ifile);
+      if (size == 0){
+        fclose(ifile);
+      }
       return -1;
     }
 //printf("before move scanline done..\n");
@@ -1548,7 +1653,9 @@ long JpegReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long
 
     jpeg_finish_decompress(&jinf);
     jpeg_destroy_decompress(&jinf);
-    fclose(ifile);
+    if (size == 0){
+      fclose(ifile);
+    }
     return 0;
 }
 
