@@ -236,11 +236,16 @@ long WSDbtronScrFrameDev::setValue(long kind,void* data){
                  }
                }
 #else
-               setDefaultRegion();
-               _setup_pixmap(_h_scr_pos,_v_scr_pos,_w_w,_w_h,_bg,_bg_pix);
-               exposeExecute(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
-               _copy_area(_h_scr_pos,_v_scr_pos,_w_w,_w_h,
-                              _h_scr_pos,_v_scr_pos, WS_PIXMAP_TO_WINDOW);
+//               setDefaultRegion();
+//               _setup_pixmap(_h_scr_pos,_v_scr_pos,_w_w,_w_h,_bg,_bg_pix);
+//               exposeExecute(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
+#if 0
+               recursiveExposeExecute(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
+#else
+               addRecursiveUpdateList();
+#endif
+//               _copy_area(_h_scr_pos,_v_scr_pos,_w_w,_w_h,
+//                              _h_scr_pos,_v_scr_pos, WS_PIXMAP_TO_WINDOW);
 #endif
              }
              return WS_NO_ERR;
@@ -358,11 +363,16 @@ long WSDbtronScrFrameDev::setValue(long kind,void* data){
                  }
                }
 #else
-               setDefaultRegion();
-               _setup_pixmap(_h_scr_pos,_v_scr_pos,_w_w,_w_h,_bg,_bg_pix);
-               exposeExecute(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
-               _copy_area(_h_scr_pos,_v_scr_pos,_w_w,_w_h,
-                              _h_scr_pos,_v_scr_pos, WS_PIXMAP_TO_WINDOW);
+///               setDefaultRegion();
+//               _setup_pixmap(_h_scr_pos,_v_scr_pos,_w_w,_w_h,_bg,_bg_pix);
+//               exposeExecute(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
+#if 0
+               recursiveExposeExecute(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
+#else
+                 addRecursiveUpdateList();
+#endif
+//               _copy_area(_h_scr_pos,_v_scr_pos,_w_w,_w_h,
+//                              _h_scr_pos,_v_scr_pos, WS_PIXMAP_TO_WINDOW);
 #endif
              }
              return WS_NO_ERR;
@@ -591,4 +601,6 @@ void WSDbtronScrFrameDev::_clear_area(long x,long y,WSCulong w,WSCulong h){
   WSDbtronFormDev::_clear_area(x,y,w,h);
 #endif
 } 
-
+void WSDbtronScrFrameDev::recursive_update(){
+  recursiveExposeExecute(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
+}
