@@ -32,7 +32,7 @@
 extern "C" {
 #include <jpeglib.h>
 extern long JpegReadFileToPixmap(Display* display,Window window,GC gc,
-             char* filename,Pixmap* pixmap,long* w,long* h);
+             char* filename,long size,Pixmap* pixmap,long* w,long* h);
 extern long JpegWriteBufToFp(FILE* fp, char* buf,long width,long height);
 };
 
@@ -45,8 +45,76 @@ static int chandler(j_decompress_ptr jinf){
 return TRUE;
 }
 
-long JpegReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pixmap* pixmap,long* w,long* h){
+typedef struct {
+  struct jpeg_source_mgr pub;
+  char* buf;
+  char buf_term[2];
+  long buf_size;
+  long pos;
+  WSCbool read_started;
+}buf_source_mgr;
 
+void init_source_from_buf(j_decompress_ptr cinfo){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  src->read_started = True;
+}
+
+void skip_input_data_from_buf(j_decompress_ptr cinfo, long nbytes){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  if (nbytes > 0) {
+    src->pub.next_input_byte += (size_t) nbytes;
+    src->pub.bytes_in_buffer -= (size_t) nbytes;
+  }
+}
+
+boolean fill_input_buffer_from_buf(j_decompress_ptr cinfo){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+
+  if (src->pos == src->buf_size){
+    src->buf_term[0] = (JOCTET) 0xFF;
+    src->buf_term[1] = (JOCTET) JPEG_EOI;
+    src->pub.next_input_byte = (JOCTET*)src->buf_term;
+    src->pub.bytes_in_buffer = 2;
+    src->read_started = False;
+    return TRUE;
+  }
+
+  src->pub.next_input_byte = (JOCTET*)src->buf;
+  src->pub.bytes_in_buffer = src->buf_size;
+  src->pos = src->buf_size;
+  src->read_started = False;
+
+  return TRUE;
+}
+
+void term_source_from_buf(j_decompress_ptr cinfo){
+}
+
+void jpeg_buf_src (j_decompress_ptr cinfo, char* buf,long size){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  if (cinfo->src == NULL) {
+    cinfo->src = (struct jpeg_source_mgr *)
+      (*cinfo->mem->alloc_small) ((j_common_ptr) cinfo, JPOOL_PERMANENT,
+                 sizeof(buf_source_mgr));
+    src = (buf_source_mgr*) cinfo->src;
+  }
+
+  src = (buf_source_mgr*) cinfo->src;
+  src->pub.init_source = init_source_from_buf;
+  src->pub.fill_input_buffer = fill_input_buffer_from_buf;
+  src->pub.skip_input_data = skip_input_data_from_buf;
+  src->pub.resync_to_restart = jpeg_resync_to_restart;
+  src->pub.term_source = term_source_from_buf;
+  src->pub.bytes_in_buffer = 0;
+  src->pub.next_input_byte = (JOCTET*)NULL;
+
+  src->buf = buf;
+  src->read_started = False;
+  src->buf_size = size;
+  src->pos = 0;
+}
+
+long JpegReadFileToPixmap2(Display* display,Window window,GC gc,char* filename,long size,Pixmap* pixmap,long* w,long* h){
     int red_mask, green_mask, blue_mask;
     int red_shift, green_shift, blue_shift;
     int start_shift, msb_flag;
@@ -56,10 +124,14 @@ long JpegReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pi
     red_mask = green_mask = blue_mask = 0;
     red_shift = green_shift = blue_shift = 0;
 
-    FILE* ifile = fopen(filename,"r");
-    if (ifile == NULL){
-      return -1;
+    FILE* ifile = NULL;
+    if (size == 0){
+      ifile = fopen(filename,"r");
+      if (ifile == NULL){
+        return -1;
+      }
     }
+
     struct jpeg_decompress_struct    jinf;
     struct jpeg_error_mgr            jerr;
 
@@ -70,8 +142,19 @@ long JpegReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pi
     jpeg_create_decompress(&jinf);
     jpeg_set_marker_processor(&jinf,JPEG_COM,chandler);
 
-    jpeg_stdio_src(&jinf,ifile);
-    jpeg_read_header(&jinf,TRUE);
+    if (size == 0){
+      jpeg_stdio_src(&jinf,ifile);
+    }else{
+      jpeg_buf_src(&jinf,filename,size);
+    }
+
+    long reti = jpeg_read_header(&jinf,TRUE);
+    if (reti != JPEG_HEADER_OK){
+      if (size == 0){
+        fclose(ifile);
+      }
+      return -1;
+    }
     jpeg_calc_output_dimensions(&jinf);
 
     long display_depth = XDefaultDepth(display,XDefaultScreen(display));
@@ -129,7 +212,9 @@ long JpegReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pi
     if (XGetWindowAttributes(display,
                      RootWindow(display, DefaultScreen(display)),
                      &win_attr) == 0) {
+      if (size == 0){
         fclose(ifile);
+       }
                  return -1;
     }
     //
@@ -471,15 +556,20 @@ long JpegReadFileToPixmap(Display* display,Window window,GC gc,char* filename,Pi
     }
     XDestroyImage(image);
 
-    fclose(ifile);
+    if (size == 0){
+      fclose(ifile);
+    }
     return 0;
 }
+long JpegReadFileToPixmap(Display* display,Window window,GC gc,char* filename,long size,Pixmap* pixmap,long* w,long* h){
+  return JpegReadFileToPixmap2(display,window,gc,filename,size,pixmap,w,h);
+}
 
 long JpegWriteBufToFp(FILE* fp, char* buf,long width,long height){
   struct jpeg_compress_struct cinfo;
   struct jpeg_error_mgr jerr;
 
-  JSAMPROW row_pointer[0];
+  JSAMPROW row_pointer[1];
   int row_stride;
 
   cinfo.err = jpeg_std_error(&jerr);
