@@ -28,7 +28,7 @@
 #include <win/WSDwinFile.h>
 #include <stdio.h>
 #include <fcntl.h>
-//#include <WShttp.h>
+#include <WStcpcom.h>
 
 WSMFclassInit(WSDwinFile,WSDfile);
 
@@ -66,7 +66,7 @@ long WSDwinFile::open(char* name,char* mode){
   _file_name.setString(name);
   _file_name.delHeadSpace();
 //  _file_name.replaceString("/","\\",0);
-#if 0 //DEVELOP...
+
   char* fn = _file_name.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
   if (!strncmp("http://",fn,7)){
     char*  pbuf = NULL;
@@ -84,7 +84,7 @@ long WSDwinFile::open(char* name,char* mode){
     }
     return WS_ERR;
   }
-#endif
+
 //printf("XXZZ filename=%s mode=%s\n",_file_name.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),mode);
   _file = fopen(
              _file_name.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
