@@ -30,12 +30,13 @@
 #include <WSDfileSystem.h>
 #include <win/WSDwinAppDev.h>
 #include <win/WSDwinColor.h>
+#include <WStcpcom.h>
 
 extern "C" {
 #include <jpeglib.h>
 #include <png.h>
 };
-extern HBITMAP JpegReadFileToBitmap(char* filename,WSCulong* w,WSCulong* h);
+extern HBITMAP JpegReadFileToBitmap(char* filename,long size,WSCulong* w,WSCulong* h);
 extern HBITMAP PngReadFileToBitmap(char* filename,WSCulong* w,WSCulong* h,HBITMAP*);
 extern long WSGFxBmpReadFpToPixmap(char* fname,FILE* ifile,HBITMAP* p,HBITMAP* p2,long* w,long* h);
 extern long WSGFxBmpReadFileToPixmap(char* filename,HBITMAP* p,HBITMAP* p2,long* w,long* h);
@@ -71,13 +72,31 @@ long WSDwinImage::initialize(){
 
   WSCstring in;
   in.setString(WSGIappFileSystem()->adjustFileName( iname ));
+  WSCstring in2 = in;
   while( in.replaceString("/","\\",0) );
 
   in.replaceString(".xpm", ".png", 0);
   in.replaceString(".XPM", ".png", 0);
+dbprintf("WSDwinImage::initialize %s\n",(char*)in);
   if (in.isExist(".jpg") != -1 || in.isExist(".JPG") != -1){
     WSCulong w,h;
-    hBitmap = JpegReadFileToBitmap((char*)in,&w,&h);
+    if (strncmp("http://",in2.getString(),7)){
+      hBitmap = JpegReadFileToBitmap((char*)in,0,&w,&h);
+    }else{
+      char*  pbuf = NULL;
+      long size = 0;
+      long reti;
+      char*  ctype = NULL;
+      long  ishtml = 0;
+      WSGFloadRemoteFile(in2.getString(),&pbuf,&ctype,&size,&ishtml,1);
+dbprintf("WSGFloadRemoteFile %s pbuf=0x%x size=%d\n",(char*)in2,pbuf,size);
+      if (pbuf != NULL){
+        hBitmap = JpegReadFileToBitmap((char*)pbuf,size,&w,&h);
+        free(pbuf);
+      }else{
+        hBitmap = 0;
+      }
+    }
     if (hBitmap != 0){
       setImageWidth(w);
       setImageHeight(h);
@@ -87,6 +106,7 @@ long WSDwinImage::initialize(){
       return WS_NO_ERR;
     }
   }
+
   if (in.isExist(".png") != -1 || in.isExist(".PNG") != -1){
     WSCulong w,h;
     HBITMAP mask=0;
@@ -218,8 +238,76 @@ static void exhandler(j_common_ptr jinf){
 static int chandler(j_decompress_ptr jinf){
 return TRUE;
 }
+typedef struct {
+  struct jpeg_source_mgr pub;
+  char* buf;
+  char buf_term[2];
+  long buf_size;
+  long pos;
+  WSCbool read_started;
+}buf_source_mgr;
 
-HBITMAP JpegReadFileToBitmap(char* filename,WSCulong* w,WSCulong* h){
+void init_source_from_buf(j_decompress_ptr cinfo){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  src->read_started = True;
+}
+
+void skip_input_data_from_buf(j_decompress_ptr cinfo, long nbytes){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  if (nbytes > 0) {
+    src->pub.next_input_byte += (size_t) nbytes;
+    src->pub.bytes_in_buffer -= (size_t) nbytes;
+  }
+}
+
+boolean fill_input_buffer_from_buf(j_decompress_ptr cinfo){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+
+  if (src->pos == src->buf_size){
+    src->buf_term[0] = (JOCTET) 0xFF;
+    src->buf_term[1] = (JOCTET) JPEG_EOI;
+    src->pub.next_input_byte = (JOCTET*)src->buf_term;
+    src->pub.bytes_in_buffer = 2;
+    src->read_started = False;
+    return TRUE;
+  }
+
+  src->pub.next_input_byte = (JOCTET*)src->buf;
+  src->pub.bytes_in_buffer = src->buf_size;
+  src->pos = src->buf_size;
+  src->read_started = False;
+
+  return TRUE;
+}
+
+void term_source_from_buf(j_decompress_ptr cinfo){
+}
+
+void jpeg_buf_src (j_decompress_ptr cinfo, char* buf,long size){
+  buf_source_mgr* src = (buf_source_mgr*) cinfo->src;
+  if (cinfo->src == NULL) {
+    cinfo->src = (struct jpeg_source_mgr *)
+      (*cinfo->mem->alloc_small) ((j_common_ptr) cinfo, JPOOL_PERMANENT,
+                 sizeof(buf_source_mgr));
+    src = (buf_source_mgr*) cinfo->src;
+  }
+
+  src = (buf_source_mgr*) cinfo->src;
+  src->pub.init_source = init_source_from_buf;
+  src->pub.fill_input_buffer = fill_input_buffer_from_buf;
+  src->pub.skip_input_data = skip_input_data_from_buf;
+  src->pub.resync_to_restart = jpeg_resync_to_restart;
+  src->pub.term_source = term_source_from_buf;
+  src->pub.bytes_in_buffer = 0;
+  src->pub.next_input_byte = (JOCTET*)NULL;
+
+  src->buf = buf;
+  src->read_started = False;
+  src->buf_size = size;
+  src->pos = 0;
+}
+
+HBITMAP JpegReadFileToBitmap(char* filename,long size,WSCulong* w,WSCulong* h){
 
     int red_mask, green_mask, blue_mask;
     int red_shift, green_shift, blue_shift;
@@ -233,10 +321,13 @@ HBITMAP JpegReadFileToBitmap(char* filename,WSCulong* w,WSCulong* h){
     red_shift = green_shift = blue_shift = 0;
     WSCstring fname(filename);
     
-    FILE* ifile = fopen(fname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
+    FILE* ifile = NULL;
+    if (size == 0){
+      ifile = fopen(fname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
                         "rb");
-    if (ifile == NULL){
-      return NULL;
+      if (ifile == NULL){
+        return NULL;
+      }
     }
     struct jpeg_decompress_struct    jinf;
     struct jpeg_error_mgr            jerr;
@@ -247,11 +338,24 @@ HBITMAP JpegReadFileToBitmap(char* filename,WSCulong* w,WSCulong* h){
 
     jpeg_create_decompress(&jinf);
     jpeg_set_marker_processor(&jinf,JPEG_COM,chandler);
-
-    jpeg_stdio_src(&jinf,ifile);
+    if (size == 0){
+dbprintf("JpegReadFileToPixmap here1 local file\n");
+      jpeg_stdio_src(&jinf,ifile);
+    }else{
+dbprintf("JpegReadFileToPixmap here2 remote file size=%d\n",size);
+      jpeg_buf_src(&jinf,filename,size);
+    }
 
 WSMFtrace("1 cinf->global_state=%d\n",jinf.global_state);
-    jpeg_read_header(&jinf,TRUE);
+    long reti = jpeg_read_header(&jinf,TRUE);
+dbprintf("JpegReadFileToPixmap jpeg_read_header=%d\n",reti);
+    if (reti != JPEG_HEADER_OK){
+      if (size == 0){
+        fclose(ifile);
+      }
+      return NULL;
+    }
+
     jpeg_calc_output_dimensions(&jinf);
 WSMFtrace("2 cinf->global_state=%d\n",jinf.global_state);
     jpeg_start_decompress(&jinf);
@@ -305,7 +409,6 @@ WSMFtrace("2 cinf->global_state=%d\n",jinf.global_state);
     long j;
 
     if (components == 3){
-WSMFtrace("XXZZim1 here3\n");
 //        long end = height*width-1;
         for(i=0; i<height; i++){
           for(j=0; j<width; j++){
@@ -327,7 +430,6 @@ WSMFtrace("XXZZim1 here3\n");
         }
       }
     }else{
-WSMFtrace("XXZZim1 here1\n");
         for(i=0; i<height; i++){
           for(j=0; j<width; j++){
             r = buf[ptr]>>3;
@@ -361,7 +463,9 @@ WSMFtrace("XXZZim1 setDIBits error %s\n",filename);
       delete buf;
     }
 
-    fclose(ifile);
+    if (size == 0){
+      fclose(ifile);
+    }
     return hBitmap;
 }
 
