@@ -1038,66 +1038,11 @@ long WSDwindraw::drawStretchedImage(short x,short y,WSCushort w,WSCushort h,WSDi
     SetStretchBltMode(_hdc,STRETCH_DELETESCANS);
 
     if (pix2 == 0){
-      StretchBlt(_hdc,x,y,w,h,mdc,0,0,iw,ih,SRCCOPY);
+      int ret = StretchBlt(_hdc,x,y,w,h,mdc,0,0,iw,ih,SRCCOPY);
+dbprintf("WSDwindraw::drawStretchedImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d<-%d,%d \n",_hdc,mdc,ret,x,y,w,h,iw,ih);
     }else{
-//      StretchBlt(_hdc,x,y,w,h,mdc2,0,0,iw,ih,SRCAND);
-//      StretchBlt(_hdc,x,y,w,h,mdc,0,0,iw,ih,SRCPAINT);
-#if 0
-      HDC mdc3 = CreateCompatibleDC(_hdc);
-      HPALETTE plbk3 = SelectPalette(mdc3,pl,FALSE);
-      RealizePalette(mdc3);
-      HBITMAP pix3 = CreateCompatibleBitmap(_hdc,iw,ih);
-      HBITMAP pxbk3 = (HBITMAP)SelectObject(mdc3,(void*)pix3);
-      SetMapMode(mdc3,GetMapMode(_hdc));
-      StretchBlt(mdc3,0,0,iw,ih,_hdc,x,y,w,h,SRCCOPY);
-
-      BITMAPINFO bmi;
-      bmi.bmiHeader.biSize=sizeof(BITMAPINFOHEADER);
-      bmi.bmiHeader.biWidth=iw;
-      bmi.bmiHeader.biHeight=ih;
-      bmi.bmiHeader.biPlanes=1;
-      bmi.bmiHeader.biBitCount=24;
-      bmi.bmiHeader.biCompression=BI_RGB;
-      bmi.bmiHeader.biSizeImage=0;
-      bmi.bmiHeader.biXPelsPerMeter=0;
-      bmi.bmiHeader.biYPelsPerMeter=0;
-      bmi.bmiHeader.biClrUsed=0;
-      bmi.bmiHeader.biClrImportant=0;
-      int bytes_per_line = (iw+1)*3 & ~3;
-
-      unsigned char* buf1 = new unsigned char[bytes_per_line * ih];
-      unsigned char* buf2 = new unsigned char[bytes_per_line * ih];
-      unsigned char* buf3 = new unsigned char[bytes_per_line * ih];
-
-      GetDIBits(mdc,pix,0,ih,(void*)buf3,&bmi,DIB_RGB_COLORS);
-      GetDIBits(mdc2,pix2,0,ih,(void*)buf2,&bmi,DIB_RGB_COLORS);
-      GetDIBits(mdc3,pix3,0,ih,(void*)buf1,&bmi,DIB_RGB_COLORS);
-
-      int i,j;
-      for(i=0; i<ih; i++){
-        long ptr = i*bytes_per_line;
-        for(j=0; j<bytes_per_line; j++){
-//printf("%d,%d a=0x%x  d=0x%x",j,i,buf2[ptr],buf1[ptr]);
-          long val = buf1[ptr] * buf2[ptr] /255 + buf3[ptr] * (255 - buf2[ptr]) /255;
-//          long val = buf3[ptr];
-          buf1[ptr] = val;
-//printf(" s=0x%x out=0x%x\n",buf3[ptr],buf1[ptr]);
-          ptr++;
-        }
-      }
-      SetDIBits(mdc3,pix3,0,ih,(void*)buf1,&bmi,DIB_RGB_COLORS);
-
-      StretchBlt(_hdc,x,y,w,h,mdc3,0,0,iw,ih,SRCCOPY);
-
-      SelectObject(mdc3,pxbk3);
-      DeleteObject(pix3);
-      DeleteDC(mdc3);
-      delete buf1;
-      delete buf2;
-      delete buf3;
-#endif
-      _draw_stretch_image_with_mask(_hdc,mdc,mdc2,pix,pix2,pl,x,y,w,h,0,0,iw,ih);
-
+      _draw_stretch_image_with_mask(_hdc,mdc,mdc2,pix,pix2,pl,x,y,w,h,
+                                                            0,0,iw,ih);
     }
     if (pl != 0){
       SelectPalette(mdc,plbk,FALSE);
@@ -1131,7 +1076,7 @@ long WSDwindraw::drawImage(short x,short y,WSCushort w,WSCushort h,WSDimage* ima
     pix2 = 0;
   }
   long icon = (long)image->getValue2();
-
+dbprintf("WSDwindraw::drawImage pix=0x%x pix2=0x%x pix3=0x%x\n",pix,pix2,pix3);
   POINT p;
   p.x = image->getImageWidth();
   p.y = image->getImageHeight();
@@ -1211,12 +1156,13 @@ long WSDwindraw::drawImage(short x,short y,WSCushort w,WSCushort h,WSDimage* ima
       SetMapMode(mdc2,GetMapMode(_hdc));
     }
     if (_printer_hdc != 0){
-      x = (short)((x - _pr_x) * _pr_scale_x);
-      y = (short)((y - _pr_y) * _pr_scale_y);
-      xoff = (short)((xoff - _pr_x) * _pr_scale_x);
-      yoff = (short)((yoff - _pr_y) * _pr_scale_y);
-      dx = (short)((dx - _pr_x) * _pr_scale_x);
-      dy = (short)((dy - _pr_y) * _pr_scale_y);
+dbprintf("WSDwindraw::drawImage _pr_scale_x=%f _pr_scale_y=%f\n",_pr_scale_x,_pr_scale_y);
+//      x = (short)((x - _pr_x) * _pr_scale_x);
+//      y = (short)((y - _pr_y) * _pr_scale_y);
+//      xoff = (short)((xoff - _pr_x) * _pr_scale_x);
+//      yoff = (short)((yoff - _pr_y) * _pr_scale_y);
+      long dx2 = (short)((dx - _pr_x) * _pr_scale_x);
+      long dy2 = (short)((dy - _pr_y) * _pr_scale_y);
       WSCulong iw2 = dw;
       WSCulong ih2 = dh;
       dw = (WSCushort)(dw * _pr_scale_x);
@@ -1225,7 +1171,8 @@ long WSDwindraw::drawImage(short x,short y,WSCushort w,WSCushort h,WSDimage* ima
       WSCulong iw = image->getImageWidth();
       WSCulong ih = image->getImageHeight();
       if (pix2 == 0){
-        StretchBlt(_hdc,dx,dy,dw,dh,mdc,dx -x -xoff,dy-y-yoff,iw2,ih2,SRCCOPY);
+        int ret = StretchBlt(_hdc,dx2,dy2,dw,dh,mdc,dx -x -xoff,dy-y-yoff,iw2,ih2,SRCCOPY);
+dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d->%d,%d \n",_hdc,mdc,ret,dx,dy,dw,dh,dx -x -xoff,dy-y-yoff);
       }else{
 //        StretchBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x -xoff,dy-y-yoff,iw2,ih2,SRCAND);
 //        BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
@@ -1238,7 +1185,8 @@ long WSDwindraw::drawImage(short x,short y,WSCushort w,WSCushort h,WSDimage* ima
       }
     }else{
       if (pix2 == 0){
-        BitBlt(_hdc,dx,dy,dw,dh,mdc,dx -x -xoff,dy -y -yoff,SRCCOPY);
+        int ret = BitBlt(_hdc,dx,dy,dw,dh,mdc,dx -x -xoff,dy -y -yoff,SRCCOPY);
+dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d->%d,%d \n",_hdc,mdc,ret,dx,dy,dw,dh,dx -x -xoff,dy-y-yoff);
       }else{
         HDC mdc3 = CreateCompatibleDC(_hdc);
         HPALETTE plbk3 = SelectPalette(mdc3,pl,FALSE);
@@ -1375,12 +1323,12 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
     SetMapMode(mdc2,GetMapMode(_hdc));
   } 
   if (_printer_hdc != 0){
-    x = (short)((x - _pr_x) * _pr_scale_x);
-    y = (short)((y - _pr_y) * _pr_scale_y);
-    sx = (short)((sx - _pr_x) * _pr_scale_x);
-    sy = (short)((sy - _pr_y) * _pr_scale_y);
-    dx = (short)((dx - _pr_x) * _pr_scale_x);
-    dy = (short)((dy - _pr_y) * _pr_scale_y);
+//    x = (short)((x - _pr_x) * _pr_scale_x);
+//    y = (short)((y - _pr_y) * _pr_scale_y);
+//    sx = (short)((sx - _pr_x) * _pr_scale_x);
+//    sy = (short)((sy - _pr_y) * _pr_scale_y);
+    long dx2 = (short)((dx - _pr_x) * _pr_scale_x);
+    long dy2 = (short)((dy - _pr_y) * _pr_scale_y);
     WSCulong iw2 = dw;
     WSCulong ih2 = dh;
     dw = (WSCushort)(dw * _pr_scale_x);
@@ -1389,7 +1337,7 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
     WSCulong iw = image->getImageWidth();
     WSCulong ih = image->getImageHeight();
     if (pix2 == 0){
-      StretchBlt(_hdc,dx,dy,dw,dh,mdc,dx -x +sx,dy -y +sy,iw2,ih2,SRCCOPY);
+      StretchBlt(_hdc,dx2,dy2,dw,dh,mdc,dx -x +sx,dy -y +sy,iw2,ih2,SRCCOPY);
     }else{
 //      StretchBlt(_hdc,dx,dy,dw,dh,mdc2,dx -x +sx,dy -y +sy,iw2,ih2,SRCAND);
 //      BitBlt(mdc2,0,0,iw,ih,mdc2,0,0,DSTINVERT);
